@@ -7,6 +7,7 @@ import tempdirs
 
 from linkins import link
 
+
 @tempdirs.makedirs(2)
 def test_make_simple(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -24,6 +25,7 @@ def test_make_simple(**kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 def test_make_nested_dirs(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -47,6 +49,7 @@ def test_make_nested_dirs(**kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 def test_make_nested_dirs_empty(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -58,6 +61,7 @@ def test_make_nested_dirs_empty(**kwargs):
     )
     assert os.listdir(linkdir) == []
 
+
 @tempdirs.makedirs(2)
 def test_make_many_dirs(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -91,6 +95,7 @@ def test_make_many_dirs(**kwargs):
     with open(folink) as fp:
         assert fp.read() == 'fo source content'
 
+
 @tempdirs.makedirs(2)
 def test_make_many_files(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -116,6 +121,7 @@ def test_make_many_files(**kwargs):
     with open(barlink) as fp:
         assert fp.read() == 'bar source content'
 
+
 @tempdirs.makedirs()
 def test_make_bad_linkdir(**kwargs):
     (srcdir,) = kwargs['tempdirs_dirs']
@@ -124,10 +130,11 @@ def test_make_bad_linkdir(**kwargs):
         link.make,
         srcdir=srcdir,
         linkdir='',
-        )
+    )
     assert res.type == ValueError
     assert res.value.message == 'Link directory "" does not exist'
 
+
 @tempdirs.makedirs()
 def test_make_bad_srcdir(**kwargs):
     (linkdir,) = kwargs['tempdirs_dirs']
@@ -136,10 +143,11 @@ def test_make_bad_srcdir(**kwargs):
         link.make,
         srcdir='',
         linkdir=linkdir,
-        )
+    )
     assert res.type == ValueError
     assert res.value.message == 'Target directory "" does not exist'
 
+
 @tempdirs.makedirs(2)
 def test_make_dir_exists(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -160,6 +168,7 @@ def test_make_dir_exists(**kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 def test_make_file_exists(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -183,6 +192,7 @@ def test_make_file_exists(**kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 def test_make_nested_dir_exists(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -207,6 +217,7 @@ def test_make_nested_dir_exists(**kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 def test_make_nested_file_exists(**kwargs):
     (srcdir, linkdir) = kwargs['tempdirs_dirs']
@@ -236,6 +247,7 @@ def test_make_nested_file_exists(**kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_has_file(fakelog, **kwargs):
@@ -257,6 +269,7 @@ def test_make_linkdir_has_file(fakelog, **kwargs):
     )
     assert fakelog.mock_calls == [error]
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_has_link(fakelog, **kwargs):
@@ -277,6 +290,7 @@ def test_make_linkdir_has_link(fakelog, **kwargs):
     )
     assert fakelog.mock_calls == [error]
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_force_file(fakelog, **kwargs):
@@ -304,6 +318,7 @@ def test_make_linkdir_force_file(fakelog, **kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_force_same_link(fakelog, **kwargs):
@@ -330,6 +345,7 @@ def test_make_linkdir_force_same_link(fakelog, **kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(3)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_force_different_link(
@@ -362,6 +378,7 @@ def test_make_linkdir_force_different_link(
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 @mock.patch('os.unlink')
@@ -385,7 +402,7 @@ def test_make_linkdir_unlink_oserror(
         srcdir=srcdir,
         linkdir=linkdir,
         force=True,
-        )
+    )
     debug = mock.call.debug(
         '{linkfile} already exists. Replacing.'.format(
             linkfile=linkfile,
@@ -397,6 +414,7 @@ def test_make_linkdir_unlink_oserror(
     assert res.type == OSError
     assert res.value.errno == errno.EXDEV
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 @mock.patch('os.unlink')
@@ -412,6 +430,7 @@ def test_make_linkdir_unlink_oserror_enoent(
         fp.write('source content')
     with open(linkfile, 'w') as fp:
         fp.write('existing content')
+
     def side_effect(*args):
         os.remove(linkfile)
         error = OSError()
@@ -437,6 +456,7 @@ def test_make_linkdir_unlink_oserror_enoent(
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.script.runscript')
 def test_make_script_simple(fakerun, **kwargs):
@@ -457,10 +477,11 @@ def test_make_script_simple(fakerun, **kwargs):
         '.',
         name='./foo-script',
         multiprocess=False,
-        )
+    )
     assert fakerun.mock_calls == [run]
     assert os.listdir(linkdir) == []
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.script.runscript')
 def test_make_script_many_files(fakerun, **kwargs):
@@ -485,7 +506,7 @@ def test_make_script_many_files(fakerun, **kwargs):
         '.',
         name='./foo-script',
         multiprocess=False,
-        )
+    )
     assert fakerun.mock_calls == [run]
     assert os.listdir(linkdir) == ['foo']
     assert os.path.isfile(srcfile)
@@ -493,6 +514,7 @@ def test_make_script_many_files(fakerun, **kwargs):
     with open(linkfile) as fp:
         assert fp.read() == 'source content'
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.script.runscript')
 def test_make_script_nested_dir(fakerun, **kwargs):
@@ -515,10 +537,11 @@ def test_make_script_nested_dir(fakerun, **kwargs):
         'foo',
         name='foo/bar-script',
         multiprocess=False,
-        )
+    )
     assert fakerun.mock_calls == [run]
     assert os.listdir(linkdir) == ['foo']
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.script.runscript')
 def test_make_script_many_scripts(fakerun, **kwargs):
@@ -544,7 +567,7 @@ def test_make_script_many_scripts(fakerun, **kwargs):
         '.',
         name='./bar-script',
         multiprocess=False,
-        )
+    )
     runnested = mock.call(
         scriptnested,
         srcdir,
@@ -552,14 +575,15 @@ def test_make_script_many_scripts(fakerun, **kwargs):
         'foo',
         name='foo/bar-script',
         multiprocess=False,
-        )
+    )
     calls = [
         run,
         runnested,
-        ]
+    ]
     assert fakerun.mock_calls == calls
     assert os.listdir(linkdir) == ['foo']
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.script.runscript')
 def test_make_script_no_run(fakerun, **kwargs):
@@ -575,6 +599,7 @@ def test_make_script_no_run(fakerun, **kwargs):
     assert fakerun.mock_calls == []
     assert os.listdir(linkdir) == []
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.script.runscript')
 def test_make_script_no_run_nested(fakerun, **kwargs):
@@ -592,6 +617,7 @@ def test_make_script_no_run_nested(fakerun, **kwargs):
     assert fakerun.mock_calls == []
     assert os.listdir(linkdir) == []
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.script.runscript')
 def test_make_script_multiprocess(fakerun, **kwargs):
@@ -613,10 +639,11 @@ def test_make_script_multiprocess(fakerun, **kwargs):
         '.',
         name='./foo-script',
         multiprocess=True,
-        )
+    )
     assert fakerun.mock_calls == [run]
     assert os.listdir(linkdir) == []
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_clean_file(fakelog, **kwargs):
@@ -642,6 +669,7 @@ def test_make_linkdir_clean_file(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_clean_link(fakelog, **kwargs):
@@ -666,6 +694,7 @@ def test_make_linkdir_clean_link(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_clean_nested_dirs(fakelog, **kwargs):
@@ -694,6 +723,7 @@ def test_make_linkdir_clean_nested_dirs(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_clean_dir_exists(fakelog, **kwargs):
@@ -721,6 +751,7 @@ def test_make_linkdir_clean_dir_exists(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_clean_file_exists(fakelog, **kwargs):
@@ -751,6 +782,7 @@ def test_make_linkdir_clean_file_exists(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_clean_nested_dir_exists(fakelog, **kwargs):
@@ -782,6 +814,7 @@ def test_make_linkdir_clean_nested_dir_exists(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_clean_nested_file_exists(fakelog, **kwargs):
@@ -818,6 +851,7 @@ def test_make_linkdir_clean_nested_file_exists(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_dir(fakelog, **kwargs):
@@ -841,6 +875,7 @@ def test_make_linkdir_exclude_dir(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_file(fakelog, **kwargs):
@@ -862,6 +897,7 @@ def test_make_linkdir_exclude_file(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_nested_dir(fakelog, **kwargs):
@@ -885,6 +921,7 @@ def test_make_linkdir_exclude_nested_dir(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_nested_file(fakelog, **kwargs):
@@ -908,6 +945,7 @@ def test_make_linkdir_exclude_nested_file(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_many_files(fakelog, **kwargs):
@@ -941,6 +979,7 @@ def test_make_linkdir_exclude_many_files(fakelog, **kwargs):
     assert os.path.isfile(srcfee)
     assert not os.path.exists(linkfee)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_multiple(fakelog, **kwargs):
@@ -971,6 +1010,7 @@ def test_make_linkdir_exclude_multiple(fakelog, **kwargs):
     assert not os.path.exists(linkbar)
     assert not os.path.exists(linkfoo)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_empty(fakelog, **kwargs):
@@ -989,6 +1029,7 @@ def test_make_linkdir_exclude_empty(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_other(fakelog, **kwargs):
@@ -1007,6 +1048,7 @@ def test_make_linkdir_exclude_other(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_clean(fakelog, **kwargs):
@@ -1030,6 +1072,7 @@ def test_make_linkdir_exclude_clean(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 @mock.patch('linkins.script.runscript')
@@ -1052,6 +1095,7 @@ def test_make_linkdir_exclude_script(fakerun, fakelog, **kwargs):
     assert fakelog.mock_calls == [debug]
     assert os.listdir(linkdir) == []
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_dir_regex(fakelog, **kwargs):
@@ -1075,6 +1119,7 @@ def test_make_linkdir_exclude_dir_regex(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_file_regex(fakelog, **kwargs):
@@ -1096,6 +1141,7 @@ def test_make_linkdir_exclude_file_regex(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_file_regex_other(fakelog, **kwargs):
@@ -1114,6 +1160,7 @@ def test_make_linkdir_exclude_file_regex_other(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_file_regex_complex(fakelog, **kwargs):
@@ -1135,6 +1182,7 @@ def test_make_linkdir_exclude_file_regex_complex(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_file_regex_nested(fakelog, **kwargs):
@@ -1158,6 +1206,7 @@ def test_make_linkdir_exclude_file_regex_nested(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert not os.path.exists(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_file_regex_many_files(fakelog, **kwargs):
@@ -1185,6 +1234,7 @@ def test_make_linkdir_exclude_file_regex_many_files(fakelog, **kwargs):
     assert os.path.isfile(srcfoo)
     assert not os.path.exists(linkfoo)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_exclude_file_regex_multiple(fakelog, **kwargs):
@@ -1215,6 +1265,7 @@ def test_make_linkdir_exclude_file_regex_multiple(fakelog, **kwargs):
     assert os.path.isfile(srcfoo)
     assert not os.path.exists(linkfoo)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_dir(fakelog, **kwargs):
@@ -1237,6 +1288,7 @@ def test_make_linkdir_include_dir(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_file(fakelog, **kwargs):
@@ -1255,6 +1307,7 @@ def test_make_linkdir_include_file(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_dir_regex(fakelog, **kwargs):
@@ -1277,6 +1330,7 @@ def test_make_linkdir_include_dir_regex(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_file_regex(fakelog, **kwargs):
@@ -1295,6 +1349,7 @@ def test_make_linkdir_include_file_regex(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_empty(fakelog, **kwargs):
@@ -1313,6 +1368,7 @@ def test_make_linkdir_include_empty(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_other(fakelog, **kwargs):
@@ -1331,6 +1387,7 @@ def test_make_linkdir_include_other(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_exclude_dir(fakelog, **kwargs):
@@ -1354,6 +1411,7 @@ def test_make_linkdir_include_exclude_dir(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_exclude_file(fakelog, **kwargs):
@@ -1373,6 +1431,7 @@ def test_make_linkdir_include_exclude_file(fakelog, **kwargs):
     assert os.path.isfile(srcfile)
     assert os.path.islink(linkfile)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_multiple_exclude(fakelog, **kwargs):
@@ -1392,12 +1451,13 @@ def test_make_linkdir_include_multiple_exclude(fakelog, **kwargs):
         include=['foo', 'bar'],
     )
     assert fakelog.mock_calls == []
-    assert os.listdir(linkdir) == ['bar', 'foo']
+    assert sorted(os.listdir(linkdir)) == sorted(['foo', 'bar'])
     assert os.path.isfile(srcbar)
     assert os.path.isfile(srcfoo)
     assert os.path.islink(linkbar)
     assert os.path.islink(linkfoo)
 
+
 @tempdirs.makedirs(2)
 @mock.patch('linkins.link.log')
 def test_make_linkdir_include_exclude_multiple(fakelog, **kwargs):
